import { Helmet } from "react-helmet";
import { lazy, Suspense, useEffect, useState, useRef } from "react";
import { COMPANY_NAME } from "@/lib/constants";
import { homeSchemas } from "@/lib/schemas/home-schemas";

// Import critical component directly for First Contentful Paint
// Only use a minimal version initially for fastest paint time
import MinimalHero from "../components/sections/minimal-hero";

// Lazy load non-critical components - with prefetch: false to reduce initial load
const Hero = lazy(() => import("@/components/sections/hero"));
const Services = lazy(() => import("@/components/sections/services"));
const Video = lazy(() => import("@/components/sections/video"));
const Team = lazy(() => import("@/components/sections/team"));
const Contact = lazy(() => import("@/components/sections/contact"));
const ReviewsCarousel = lazy(() => import("@/components/sections/reviews-carousel"));

// Simple static loading component - no animations
const SectionLoader = () => (
  <div className="w-full h-[400px] bg-gray-100 rounded-lg" />
);

export default function Home() {
  // Track when the full hero component can be shown
  const [showFullHero, setShowFullHero] = useState(false);
  const [fcp, setFcp] = useState(false);
  
  // Mark First Contentful Paint as complete and schedule loading of full hero
  useEffect(() => {
    // Mark First Contentful Paint as ready
    setFcp(true);
    
    // After minimal content is shown, load the complete hero
    // Use requestIdleCallback to wait for an idle period
    if ('requestIdleCallback' in window) {
      (window as any).requestIdleCallback(() => {
        setShowFullHero(true);
      }, { timeout: 2000 });
    } else {
      // Fallback for browsers without requestIdleCallback
      setTimeout(() => {
        setShowFullHero(true);
      }, 1000); // Longer delay to ensure other critical resources load first
    }
    
    return () => {};
  }, []);

  // Reference for scroll progress indicator
  const progressRef = useRef<HTMLDivElement>(null);
  
  // Update progress bar on scroll - simple implementation instead of animation library
  useEffect(() => {
    if (!fcp) return;
    
    const updateProgress = () => {
      if (!progressRef.current) return;
      const scrollTop = window.scrollY;
      const docHeight = document.body.offsetHeight - window.innerHeight;
      const scrollPercent = scrollTop / docHeight;
      progressRef.current.style.width = `${scrollPercent * 100}%`;
    };
    
    window.addEventListener('scroll', updateProgress);
    return () => window.removeEventListener('scroll', updateProgress);
  }, [fcp]);

  return (
    <>
      <Helmet>
        <title>Expert Solicitors in Stockport, Greater Manchester | {COMPANY_NAME}</title>
        <meta name="description" content="Leading solicitors in Greater Manchester offering expert legal services in wills & probate, conveyancing, and lasting powers of attorney. Over 25 years of professional experience serving Stockport and surrounding areas." />
        <meta name="geo.region" content="GB-MAN" />
        <meta name="geo.placename" content="Stockport" />
        <meta name="geo.position" content="53.4084;-2.1600" />
        <meta name="ICBM" content="53.4084, -2.1600" />
        <link rel="canonical" href="https://bjmckenna.com" />
        
        {/* Preload critical hero image */}
        <link rel="preload" href="/images/office-4.webp" as="image" type="image/webp" fetchPriority="high" />
      </Helmet>

      {/* Simple static progress indicator */}
      {fcp && (
        <div className="fixed top-0 left-0 right-0 h-1 bg-primary/20 z-50">
          <div 
            ref={progressRef}
            className="h-full bg-primary w-0 transition-all duration-300 ease-out" 
          />
        </div>
      )}

      <div className="relative">
        {/* Hero section - critical for first paint */}
        <div className="relative z-10">
          {!showFullHero ? (
            <MinimalHero />
          ) : (
            <Suspense fallback={<MinimalHero />}>
              <Hero />
            </Suspense>
          )}
        </div>

        {/* Only render these sections after FCP */}
        {fcp && (
          <>
            <div className="relative z-30 py-12 bg-gradient-to-b from-gray-50 to-white">
              <Suspense fallback={<SectionLoader />}>
                <Services />
              </Suspense>
            </div>

            <div className="relative z-40 py-12">
              <Suspense fallback={<SectionLoader />}>
                <Video />
              </Suspense>
            </div>

            <div className="relative z-50 py-12 bg-gray-50">
              <Suspense fallback={<SectionLoader />}>
                <Team />
              </Suspense>
            </div>

            <div className="relative z-60 py-12">
              <Suspense fallback={<SectionLoader />}>
                <ReviewsCarousel />
              </Suspense>
            </div>

            <div className="relative z-70 py-12 bg-primary/5">
              <Suspense fallback={<SectionLoader />}>
                <Contact />
              </Suspense>
            </div>
          </>
        )}
      </div>
    </>
  );
}